@@ -15,6 +15,10 @@ def normalize_key(key):
     return s.normalize_key(key)
 
 
+def normalize_record(record, strict = False):
+
+    return s.normalize_record(record, strict)
+
 def get_keys(record_type):
 
     return s.get_keys(record_type)
@@ -25,3 +29,5 @@ def get_datatype(record_type, key):
     return s.get_datatype(record_type, key)
 
 
+def get_record_id(record):
+    return s.get_record_id(record)
\ No newline at end of file
